@@ -11,11 +11,12 @@
 #include <KCompressionDevice>
 // Qt
 #include <QBuffer>
-#include <QFile>
-#include <QString>
+#include <QDebug>
 #include <QDomElement>
 #include <QDomNode>
-#include <QDebug>
+#include <QFile>
+#include <QRegExp>
+#include <QString>
 // Std
 #include <cmath>
 
@@ -32,16 +33,17 @@
  */
 class KGameSvgDocumentPrivate
 {
-    public:
-
+public:
     /**
      * @brief Instantiates a KGameSvgDocumentPrivate object
      */
     KGameSvgDocumentPrivate()
-    {}
+    {
+    }
 
     ~KGameSvgDocumentPrivate()
-    {}
+    {
+    }
 
     /**
      * @brief Performs a preorder traversal of the DOM tree to find element matching @c attributeName & @c attributeValue
@@ -51,7 +53,7 @@ class KGameSvgDocumentPrivate
      * @param node The node to start the traversal from.
      * @returns the node with id of @c elementId.  If no node has that id, returns a null node.
      */
-    QDomNode findElementById(const QString& attributeName, const QString& attributeValue, const QDomNode& node);
+    QDomNode findElementById(const QString &attributeName, const QString &attributeValue, const QDomNode &node);
 
     /**
      * @brief Returns the current element
@@ -122,32 +124,33 @@ class KGameSvgDocumentPrivate
      * @brief Whether the style attribute has a trailing semicolon
      */
     bool m_hasSemicolon;
-
-
 };
 
 const QString KGameSvgDocumentPrivate::SVG_XML_PREPEND = QStringLiteral("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><svg>");
 const QString KGameSvgDocumentPrivate::SVG_XML_APPEND = QStringLiteral("</svg>");
 
 KGameSvgDocument::KGameSvgDocument()
-    : QDomDocument(), d(new KGameSvgDocumentPrivate)
-{}
+    : QDomDocument()
+    , d(new KGameSvgDocumentPrivate)
+{
+}
 
 KGameSvgDocument::KGameSvgDocument(const KGameSvgDocument &doc)
-    : QDomDocument(), d(new KGameSvgDocumentPrivate(*doc.d))
+    : QDomDocument()
+    , d(new KGameSvgDocumentPrivate(*doc.d))
 {
 }
 
 KGameSvgDocument::~KGameSvgDocument() = default;
 
-KGameSvgDocument& KGameSvgDocument::operator=(const KGameSvgDocument &doc)
+KGameSvgDocument &KGameSvgDocument::operator=(const KGameSvgDocument &doc)
 {
     QDomDocument::operator=(doc);
     *d = *doc.d;
     return *this;
 }
 
-QDomNode KGameSvgDocument::elementByUniqueAttributeValue(const QString& attributeName, const QString& attributeValue)
+QDomNode KGameSvgDocument::elementByUniqueAttributeValue(const QString &attributeName, const QString &attributeValue)
 {
     /* DOM is always "live", so there maybe a new root node.  We always have to ask for the
      * root node instead of keeping a pointer to it.
@@ -160,22 +163,20 @@ QDomNode KGameSvgDocument::elementByUniqueAttributeValue(const QString& attribut
     return node;
 }
 
-QDomNode KGameSvgDocument::elementById(const QString& attributeValue)
+QDomNode KGameSvgDocument::elementById(const QString &attributeValue)
 {
-    return elementByUniqueAttributeValue(QStringLiteral( "id" ), attributeValue);
+    return elementByUniqueAttributeValue(QStringLiteral("id"), attributeValue);
 }
 
 void KGameSvgDocument::load()
 {
-    if (d->m_svgFilename.isNull())
-    {
+    if (d->m_svgFilename.isNull()) {
         qCDebug(GAMES_LIB) << "KGameSvgDocument::load(): Filename not specified.";
         return;
     }
 
     QFile file(d->m_svgFilename);
-    if (!file.open(QIODevice::ReadOnly))
-    {
+    if (!file.open(QIODevice::ReadOnly)) {
         return;
     }
     QByteArray content = file.readAll();
@@ -185,8 +186,7 @@ void KGameSvgDocument::load()
     {
         QBuffer buf(&content);
         KCompressionDevice flt(&buf, /*autoDeleteInputDevice*/ false, KCompressionDevice::GZip);
-	if (!flt.open(QIODevice::ReadOnly))
-        {
+        if (!flt.open(QIODevice::ReadOnly)) {
             flt.close();
             return;
         }
@@ -195,8 +195,7 @@ void KGameSvgDocument::load()
         content = ar;
     }
 
-    if (!setContent(content))
-    {
+    if (!setContent(content)) {
         file.close();
         qCDebug(GAMES_LIB) << "DOM content not set.";
         return;
@@ -204,61 +203,52 @@ void KGameSvgDocument::load()
     file.close();
 }
 
-void KGameSvgDocument::load(const QString& svgFilename)
+void KGameSvgDocument::load(const QString &svgFilename)
 {
     setSvgFilename(svgFilename);
     load();
 }
 
-void KGameSvgDocument::rotate(double degrees, const MatrixOptions& options)
+void KGameSvgDocument::rotate(double degrees, const MatrixOptions &options)
 {
     QTransform matrix;
 
-    if (options == ApplyToCurrentMatrix)
-    {
+    if (options == ApplyToCurrentMatrix) {
         matrix = transformMatrix().QTransform::rotate(degrees);
-    }
-    else
-    {
+    } else {
         matrix = QTransform();
         matrix.QTransform::rotate(degrees);
     }
     setTransformMatrix(matrix, ReplaceCurrentMatrix);
 }
 
-void KGameSvgDocument::translate(int xPixels, int yPixels, const MatrixOptions& options)
+void KGameSvgDocument::translate(int xPixels, int yPixels, const MatrixOptions &options)
 {
     QTransform matrix;
 
-    if (options == ApplyToCurrentMatrix)
-    {
+    if (options == ApplyToCurrentMatrix) {
         matrix = transformMatrix().QTransform::translate(xPixels, yPixels);
-    }
-    else
-    {
+    } else {
         matrix = QTransform();
         matrix.QTransform::translate(xPixels, yPixels);
     }
     setTransformMatrix(matrix, ReplaceCurrentMatrix);
 }
 
-void KGameSvgDocument::shear(double xRadians, double yRadians, const MatrixOptions& options)
+void KGameSvgDocument::shear(double xRadians, double yRadians, const MatrixOptions &options)
 {
     QTransform matrix;
 
-    if (options == ApplyToCurrentMatrix)
-    {
+    if (options == ApplyToCurrentMatrix) {
         matrix = transformMatrix().QTransform::shear(xRadians, yRadians);
-    }
-    else
-    {
+    } else {
         matrix = QTransform();
         matrix.QTransform::shear(xRadians, yRadians);
     }
     setTransformMatrix(matrix, ReplaceCurrentMatrix);
 }
 
-void KGameSvgDocument::skew(double xDegrees, double yDegrees, const MatrixOptions& options)
+void KGameSvgDocument::skew(double xDegrees, double yDegrees, const MatrixOptions &options)
 {
     double xRadians = xDegrees * (M_PI / 180);
     double yRadians = yDegrees * (M_PI / 180);
@@ -266,20 +256,16 @@ void KGameSvgDocument::skew(double xDegrees, double yDegrees, const MatrixOption
     shear(xRadians, yRadians, options);
 }
 
-void KGameSvgDocument::scale(double xFactor, double yFactor, const MatrixOptions& options)
+void KGameSvgDocument::scale(double xFactor, double yFactor, const MatrixOptions &options)
 {
     QTransform matrix;
-    if ((xFactor == 0) || (yFactor == 0))
-    {
-        qWarning () << "KGameSvgDocument::scale: You cannot scale by zero";
+    if ((xFactor == 0) || (yFactor == 0)) {
+        qWarning() << "KGameSvgDocument::scale: You cannot scale by zero";
     }
 
-    if (options == ApplyToCurrentMatrix)
-    {
+    if (options == ApplyToCurrentMatrix) {
         matrix = transformMatrix().QTransform::scale(xFactor, yFactor);
-    }
-    else
-    {
+    } else {
         matrix = QTransform();
         matrix.QTransform::scale(xFactor, yFactor);
     }
@@ -291,7 +277,7 @@ QDomNode KGameSvgDocument::currentNode() const
     return d->m_currentNode;
 }
 
-void KGameSvgDocument::setCurrentNode(const QDomNode& node)
+void KGameSvgDocument::setCurrentNode(const QDomNode &node)
 {
     d->m_currentNode = node;
     d->setCurrentElement();
@@ -302,17 +288,17 @@ QString KGameSvgDocument::svgFilename() const
     return d->m_svgFilename;
 }
 
-void KGameSvgDocument::setSvgFilename(const QString& svgFilename)
+void KGameSvgDocument::setSvgFilename(const QString &svgFilename)
 {
     d->m_svgFilename = svgFilename;
 }
 
-QString KGameSvgDocument::styleProperty(const QString& propertyName) const
+QString KGameSvgDocument::styleProperty(const QString &propertyName) const
 {
     return styleProperties().value(propertyName);
 }
 
-void KGameSvgDocument::setStyleProperty(const QString& propertyName, const QString& propertyValue)
+void KGameSvgDocument::setStyleProperty(const QString &propertyName, const QString &propertyValue)
 {
     QHash<QString, QString> properties;
 
@@ -335,37 +321,33 @@ QString KGameSvgDocument::nodeToSvg() const
     xml = *str.string();
 
     // Find and add any required gradients or patterns
-    pattern = QLatin1String( "url" ) + WSP_ASTERISK + OPEN_PARENS + WSP_ASTERISK + QLatin1String( "#(.*)" ) + WSP_ASTERISK + CLOSE_PARENS;
+    pattern = QLatin1String("url") + WSP_ASTERISK + OPEN_PARENS + WSP_ASTERISK + QLatin1String("#(.*)") + WSP_ASTERISK + CLOSE_PARENS;
     rx.setPattern(pattern);
-    if (rx.indexIn(xml, result) != -1)
-    {
+    if (rx.indexIn(xml, result) != -1) {
         QDomNode node, nodeBase;
         QString baseId;
         QDomNode n = def();
 
         result = 0;
-        while ((result = rx.indexIn(xml, result)) != -1)
-        {
+        while ((result = rx.indexIn(xml, result)) != -1) {
             // Find the pattern or gradient referenced
             result += rx.matchedLength();
-            if (!defsAdded.contains(rx.cap(1)))
-            {
-                node = d->findElementById(QStringLiteral( "id" ), rx.cap(1), n);
+            if (!defsAdded.contains(rx.cap(1))) {
+                node = d->findElementById(QStringLiteral("id"), rx.cap(1), n);
                 node.save(str_t, 1);
                 defsAdded.append(rx.cap(1));
             }
 
             // Find the gradient the above gradient is based on
-            baseId = node.toElement().attribute(QStringLiteral( "xlink:href" )).mid(1);
-            if (!defsAdded.contains(baseId))
-            {
-                nodeBase = d->findElementById(QStringLiteral( "id" ), baseId, n);
+            baseId = node.toElement().attribute(QStringLiteral("xlink:href")).mid(1);
+            if (!defsAdded.contains(baseId)) {
+                nodeBase = d->findElementById(QStringLiteral("id"), baseId, n);
                 nodeBase.save(str_t, 1);
                 defsAdded.append(baseId);
             }
         }
         defs = *str_t.string();
-        defs = QLatin1String( "<defs>" ) + defs + QLatin1String( "</defs>" );
+        defs = QLatin1String("<defs>") + defs + QLatin1String("</defs>");
     }
 
     // Need to make node be a real svg document, so prepend and append required tags.
@@ -380,32 +362,32 @@ QByteArray KGameSvgDocument::nodeToByteArray() const
 
 QString KGameSvgDocument::style() const
 {
-    return d->m_currentElement.attribute( QStringLiteral( "style" ), QStringLiteral( "Element has no style attribute." ));
+    return d->m_currentElement.attribute(QStringLiteral("style"), QStringLiteral("Element has no style attribute."));
 }
 
-void KGameSvgDocument::setStyle(const QString& styleAttribute)
+void KGameSvgDocument::setStyle(const QString &styleAttribute)
 {
-    d->m_currentElement.setAttribute(QStringLiteral( "style" ), styleAttribute);
+    d->m_currentElement.setAttribute(QStringLiteral("style"), styleAttribute);
 }
 
 QDomNodeList KGameSvgDocument::patterns() const
 {
-    return elementsByTagName(QStringLiteral( "pattern" ));
+    return elementsByTagName(QStringLiteral("pattern"));
 }
 
 QDomNodeList KGameSvgDocument::linearGradients() const
 {
-    return elementsByTagName(QStringLiteral( "linearGradient" ));
+    return elementsByTagName(QStringLiteral("linearGradient"));
 }
 
 QDomNodeList KGameSvgDocument::radialGradients() const
 {
-    return elementsByTagName(QStringLiteral( "radialGradient" ));
+    return elementsByTagName(QStringLiteral("radialGradient"));
 }
 
 QDomNodeList KGameSvgDocument::defs() const
 {
-    return elementsByTagName(QStringLiteral( "defs" ));
+    return elementsByTagName(QStringLiteral("defs"));
 }
 
 QDomNode KGameSvgDocument::def() const
@@ -415,12 +397,12 @@ QDomNode KGameSvgDocument::def() const
 
 QString KGameSvgDocument::transform() const
 {
-    return d->m_currentElement.attribute( QStringLiteral( "transform" ), QStringLiteral( "Element has no transform attribute." ) );
+    return d->m_currentElement.attribute(QStringLiteral("transform"), QStringLiteral("Element has no transform attribute."));
 }
 
-void KGameSvgDocument::setTransform(const QString& transformAttribute)
+void KGameSvgDocument::setTransform(const QString &transformAttribute)
 {
-    d->m_currentElement.setAttribute(QStringLiteral( "transform" ), transformAttribute);
+    d->m_currentElement.setAttribute(QStringLiteral("transform"), transformAttribute);
 }
 
 QHash<QString, QString> KGameSvgDocument::styleProperties() const
@@ -429,64 +411,59 @@ QHash<QString, QString> KGameSvgDocument::styleProperties() const
     QStringList styleProperties, keyValuePair;
     QString styleProperty;
 
-    styleProperties = style().split(QLatin1Char( ';' ));
+    styleProperties = style().split(QLatin1Char(';'));
 
     /* The style attr may have a trailing semi-colon.  If it does, split()
      * gives us an empty final element.  Remove it or we get 'index out of range' errors
      */
-    if (styleProperties.at((styleProperties.count()-1)).isEmpty())
-    {
-        styleProperties.removeAt((styleProperties.count()-1));
+    if (styleProperties.at((styleProperties.count() - 1)).isEmpty()) {
+        styleProperties.removeAt((styleProperties.count() - 1));
         d->setStyleHasTrailingSemicolon(true);
+    } else {
+        d->setStyleHasTrailingSemicolon(false);
     }
-    else {d->setStyleHasTrailingSemicolon(false);}
 
-    for (int i = 0; i < styleProperties.size(); i++)
-    {
+    for (int i = 0; i < styleProperties.size(); i++) {
         styleProperty = styleProperties.at(i);
-        keyValuePair = styleProperty.split(QLatin1Char( ':' ));
+        keyValuePair = styleProperty.split(QLatin1Char(':'));
         stylePropertiesHash.insert(keyValuePair.at(0), keyValuePair.at(1));
     }
     return stylePropertiesHash;
 }
 
-void KGameSvgDocument::setStyleProperties(const QHash<QString, QString>& _styleProperties, const StylePropertySortOptions& options)
+void KGameSvgDocument::setStyleProperties(const QHash<QString, QString> &_styleProperties, const StylePropertySortOptions &options)
 {
     QHash<QString, QString> styleProperties = _styleProperties;
     QString styleBuffer, property;
 
-    d->m_inkscapeOrder << QStringLiteral( "fill" ) << QStringLiteral( "fill-opacity" ) << QStringLiteral( "fill-rule" ) << QStringLiteral( "stroke" ) << QStringLiteral( "stroke-width" ) << QStringLiteral( "stroke-linecap" )
-                       << QStringLiteral( "stroke-linejoin" ) << QStringLiteral( "stroke-miterlimit" ) << QStringLiteral( "stroke-dasharray" ) << QStringLiteral( "stroke-opacity" );
+    d->m_inkscapeOrder << QStringLiteral("fill") << QStringLiteral("fill-opacity") << QStringLiteral("fill-rule") << QStringLiteral("stroke")
+                       << QStringLiteral("stroke-width") << QStringLiteral("stroke-linecap") << QStringLiteral("stroke-linejoin")
+                       << QStringLiteral("stroke-miterlimit") << QStringLiteral("stroke-dasharray") << QStringLiteral("stroke-opacity");
 
-    if (options == UseInkscapeOrder)
-    {
-        for (int i = 0; i < d->m_inkscapeOrder.size(); i++)
-        {
+    if (options == UseInkscapeOrder) {
+        for (int i = 0; i < d->m_inkscapeOrder.size(); i++) {
             property = d->m_inkscapeOrder.at(i);
-            if (styleProperties.contains(property))
-            {
-                styleBuffer += property + QLatin1Char( ':' ) + styleProperties.take(property) + QLatin1Char( ';' );
-            }
-            else
-            {
+            if (styleProperties.contains(property)) {
+                styleBuffer += property + QLatin1Char(':') + styleProperties.take(property) + QLatin1Char(';');
+            } else {
                 // Do Nothing
             }
         }
     }
 
     // Append any style properties
-    if (!styleProperties.isEmpty())
-    {
-        QHashIterator<QString,  QString> it(styleProperties);
-        while (it.hasNext())
-        {
+    if (!styleProperties.isEmpty()) {
+        QHashIterator<QString, QString> it(styleProperties);
+        while (it.hasNext()) {
             it.next();
-            styleBuffer += it.key() + QLatin1Char( ':' ) + it.value() + QLatin1Char( ';' );
+            styleBuffer += it.key() + QLatin1Char(':') + it.value() + QLatin1Char(';');
         }
     }
 
     // Remove trailing semicolon if original didn't have one
-    if (!d->styleHasTrailingSemicolon()) {styleBuffer.chop(1);}
+    if (!d->styleHasTrailingSemicolon()) {
+        styleBuffer.chop(1);
+    }
     setStyle(styleBuffer);
 }
 
@@ -511,16 +488,14 @@ QTransform KGameSvgDocument::transformMatrix() const
     QTransform baseMatrix = QTransform();
 
     transformAttribute = transform();
-    if (transformAttribute == QLatin1String( "Element has no transform attribute." ))
-    {
+    if (transformAttribute == QLatin1String("Element has no transform attribute.")) {
         return QTransform();
     }
     transformAttribute = transformAttribute.trimmed();
 
     rx.setPattern(TRANSFORMS);
-    if (!rx.exactMatch(transformAttribute))
-    {
-        qWarning () << "Transform attribute seems to be invalid. Check your SVG file.";
+    if (!rx.exactMatch(transformAttribute)) {
+        qWarning() << "Transform attribute seems to be invalid. Check your SVG file.";
         return QTransform();
     }
 
@@ -531,24 +506,28 @@ QTransform KGameSvgDocument::transformMatrix() const
         result = rx.indexIn(transformAttribute);
         if (result != -1) // Found left-most transform
         {
-            if (rx.cap(1) == QLatin1String( "matrix" ))
-            {
+            if (rx.cap(1) == QLatin1String("matrix")) {
                 // If the first transform found is a matrix, use it as the base,
                 // else we use a null matrix.
-                if (i == 0)
-                {
-                    baseMatrix = QTransform(rx.cap(2).toDouble(), rx.cap(3).toDouble(), rx.cap(4).toDouble(),
-                                         rx.cap(5).toDouble(), rx.cap(6).toDouble(), rx.cap(7).toDouble());
-                }
-                else
-                {
-                    baseMatrix = QTransform(rx.cap(2).toDouble(), rx.cap(3).toDouble(), rx.cap(4).toDouble(),
-                                         rx.cap(5).toDouble(), rx.cap(6).toDouble(), rx.cap(7).toDouble()) * baseMatrix;
+                if (i == 0) {
+                    baseMatrix = QTransform(rx.cap(2).toDouble(),
+                                            rx.cap(3).toDouble(),
+                                            rx.cap(4).toDouble(),
+                                            rx.cap(5).toDouble(),
+                                            rx.cap(6).toDouble(),
+                                            rx.cap(7).toDouble());
+                } else {
+                    baseMatrix = QTransform(rx.cap(2).toDouble(),
+                                            rx.cap(3).toDouble(),
+                                            rx.cap(4).toDouble(),
+                                            rx.cap(5).toDouble(),
+                                            rx.cap(6).toDouble(),
+                                            rx.cap(7).toDouble())
+                        * baseMatrix;
                 }
             }
 
-            if (rx.cap(8) == QLatin1String( "translate" ))
-            {
+            if (rx.cap(8) == QLatin1String("translate")) {
                 double x = rx.cap(9).toDouble();
                 double y = rx.cap(10).toDouble();
                 if (rx.cap(10).isEmpty()) // y defaults to zero per SVG standard
@@ -558,8 +537,7 @@ QTransform KGameSvgDocument::transformMatrix() const
                 baseMatrix = baseMatrix.translate(x, y);
             }
 
-            if (rx.cap(11) == QLatin1String( "scale" ))
-            {
+            if (rx.cap(11) == QLatin1String("scale")) {
                 double x = rx.cap(12).toDouble();
                 double y = rx.cap(12).toDouble();
                 if (rx.cap(13).isEmpty()) // y defaults to x per SVG standard
@@ -569,8 +547,7 @@ QTransform KGameSvgDocument::transformMatrix() const
                 baseMatrix = baseMatrix.scale(x, y);
             }
 
-            if (rx.cap(14) == QLatin1String( "rotate" ))
-            {
+            if (rx.cap(14) == QLatin1String("rotate")) {
                 double a = rx.cap(15).toDouble();
                 double cx = rx.cap(16).toDouble();
                 double cy = rx.cap(17).toDouble();
@@ -580,20 +557,16 @@ QTransform KGameSvgDocument::transformMatrix() const
                     baseMatrix.translate(cx, cy);
                     baseMatrix.rotate(a);
                     baseMatrix.translate((cx * -1), (cy * -1));
-                }
-                else
-                {
+                } else {
                     baseMatrix = baseMatrix.rotate(a); // rotate around origin
                 }
             }
 
-            if (rx.cap(18) == QLatin1String( "skewX" ))
-            {
+            if (rx.cap(18) == QLatin1String("skewX")) {
                 baseMatrix = baseMatrix.shear(rx.cap(19).toDouble() * (M_PI / 180), 0);
             }
 
-            if (rx.cap(20) == QLatin1String( "skewY" ))
-            {
+            if (rx.cap(20) == QLatin1String("skewY")) {
                 baseMatrix = baseMatrix.shear(0, rx.cap(21).toDouble() * (M_PI / 180));
             }
         }
@@ -604,69 +577,62 @@ QTransform KGameSvgDocument::transformMatrix() const
     return baseMatrix;
 }
 
-void KGameSvgDocument::setTransformMatrix(QTransform& matrix, const MatrixOptions& options)
+void KGameSvgDocument::setTransformMatrix(QTransform &matrix, const MatrixOptions &options)
 {
     QString transformBuffer, tmp;
     QTransform null = QTransform();
 
-    if (options == ApplyToCurrentMatrix)
-    {
+    if (options == ApplyToCurrentMatrix) {
         matrix = transformMatrix() * matrix;
     }
 
-    transformBuffer = QStringLiteral( "matrix(" );
-    transformBuffer += tmp.setNum(matrix.m11(),'g',7) + QLatin1Char( ',' );
-    transformBuffer += tmp.setNum(matrix.m12(),'g',7) + QLatin1Char( ',' );
-    transformBuffer += tmp.setNum(matrix.m21(),'g',7) + QLatin1Char( ',' );
-    transformBuffer += tmp.setNum(matrix.m22(),'g',7) + QLatin1Char( ',' );
-    transformBuffer += tmp.setNum(matrix.dx(),'g',7) + QLatin1Char( ',' );
-    transformBuffer += tmp.setNum(matrix.dy(),'g',7) + QLatin1Char( ')' );
+    transformBuffer = QStringLiteral("matrix(");
+    transformBuffer += tmp.setNum(matrix.m11(), 'g', 7) + QLatin1Char(',');
+    transformBuffer += tmp.setNum(matrix.m12(), 'g', 7) + QLatin1Char(',');
+    transformBuffer += tmp.setNum(matrix.m21(), 'g', 7) + QLatin1Char(',');
+    transformBuffer += tmp.setNum(matrix.m22(), 'g', 7) + QLatin1Char(',');
+    transformBuffer += tmp.setNum(matrix.dx(), 'g', 7) + QLatin1Char(',');
+    transformBuffer += tmp.setNum(matrix.dy(), 'g', 7) + QLatin1Char(')');
 
-    if ((transform() == QLatin1String( "Element has no transform attribute." )) && (matrix == null))
-    {
+    if ((transform() == QLatin1String("Element has no transform attribute.")) && (matrix == null)) {
         // Do not write a meaningless matrix to DOM
-    }
-    else
-    {
+    } else {
         setTransform(transformBuffer);
     }
 }
 
-
 //
 // Private
 //
 
-QDomNode KGameSvgDocumentPrivate::findElementById(const QString& attributeName, const QString& attributeValue, const QDomNode& node)
+QDomNode KGameSvgDocumentPrivate::findElementById(const QString &attributeName, const QString &attributeValue, const QDomNode &node)
 {
     QDomElement e = node.toElement(); // try to convert the node to an element.
-    QString value = e.attribute( attributeName, QStringLiteral( "Element has no attribute with that name." ));
+    QString value = e.attribute(attributeName, QStringLiteral("Element has no attribute with that name."));
 
-    if (value == attributeValue)
-    {
+    if (value == attributeValue) {
         // We found our node.  Stop recursion and return it.
         return node;
     }
 
-    if (!node.firstChild().isNull())
-    {
+    if (!node.firstChild().isNull()) {
         QDomNode result = findElementById(attributeName, attributeValue, node.firstChild());
         /** We have recursed, now we need to have this recursion end when
          * the function call above returns
          */
-        if (!result.isNull()) return result; // If we found the node with id, then return it
+        if (!result.isNull())
+            return result; // If we found the node with id, then return it
     }
-    if (!node.nextSibling().isNull())
-    {
+    if (!node.nextSibling().isNull()) {
         QDomNode result = findElementById(attributeName, attributeValue, node.nextSibling());
         /** We have recursed, now we need to have this recursion end when
          * the function call above returns */
-        if (!result.isNull()) return result;
+        if (!result.isNull())
+            return result;
     }
-    if (!node.firstChild().isNull() && !node.nextSibling().isNull())
-    {
+    if (!node.firstChild().isNull() && !node.nextSibling().isNull()) {
         // Do Nothing
-        //qCDebug(GAMES_LIB) << "No children or siblings.";
+        // qCDebug(GAMES_LIB) << "No children or siblings.";
     }
 
     // Matching node not found, so return a null node.
@@ -692,4 +658,3 @@ void KGameSvgDocumentPrivate::setStyleHasTrailingSemicolon(bool hasSemicolon)
 {
     m_hasSemicolon = hasSemicolon;
 }
-
