@@ -7,19 +7,20 @@
 #include "kgamepopupitemtest.h"
 
 // KF
-#include <KActionCollection>
-#include <KFileDialog>
-#include <KColorScheme>
 #include <KAboutData>
+#include <KActionCollection>
+#include <KColorScheme>
+#include <KFileDialog>
 #include <KLocalizedString>
 // Qt
-#include <QGraphicsScene>
-#include <QTimer>
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QGraphicsScene>
+#include <QTimer>
 
 KGpiMainWindow::KGpiMainWindow()
-    : KXmlGuiWindow(), m_replaceMode(KGamePopupItem::LeavePrevious)
+    : KXmlGuiWindow()
+    , m_replaceMode(KGamePopupItem::LeavePrevious)
 {
     QWidget *wid = new QWidget(this);
     m_mainWid.setupUi(wid);
@@ -30,8 +31,8 @@ KGpiMainWindow::KGpiMainWindow()
     KStandardAction::quit(this, &KGpiMainWindow::close, actionCollection());
 
     m_scene = new QGraphicsScene;
-    m_scene->setSceneRect( -1000, -1000, 2000, 2000 );
-    QLinearGradient gradient(QPointF(-1000,-1000), QPointF(2000,2000));
+    m_scene->setSceneRect(-1000, -1000, 2000, 2000);
+    QLinearGradient gradient(QPointF(-1000, -1000), QPointF(2000, 2000));
     gradient.setColorAt(0, Qt::white);
     gradient.setColorAt(1, Qt::blue);
 
@@ -42,9 +43,9 @@ KGpiMainWindow::KGpiMainWindow()
 
     m_mainWid.graphicsView->setScene(m_scene);
 
-    KColorScheme kcs( QPalette::Active, KColorScheme::Tooltip );
-    m_mainWid.textColor->setColor( kcs.foreground(KColorScheme::NormalText).color() );
-    m_mainWid.bkgndColor->setColor( kcs.background().color() );
+    KColorScheme kcs(QPalette::Active, KColorScheme::Tooltip);
+    m_mainWid.textColor->setColor(kcs.foreground(KColorScheme::NormalText).color());
+    m_mainWid.bkgndColor->setColor(kcs.background().color());
 
     connect(m_mainWid.popupTL, &QPushButton::clicked, this, &KGpiMainWindow::onPopupTL);
     connect(m_mainWid.popupTR, &QPushButton::clicked, this, &KGpiMainWindow::onPopupTR);
@@ -62,17 +63,17 @@ KGpiMainWindow::KGpiMainWindow()
     connect(m_mainWid.cornersType, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &KGpiMainWindow::sharpnessChanged);
 
     connect(m_mainWid.mesTimeout, static_cast<void (KIntSpinBox::*)(int)>(&KIntSpinBox::valueChanged), this, &KGpiMainWindow::onTimeoutChanged);
-    m_mainWid.mesTimeout->setValue( m_popupItem->messageTimeout() );
-    m_mainWid.mesTimeout->setSuffix( ki18np(" millisecond", " milliseconds") );
-    m_mainWid.opacity->setValue( static_cast<int>(m_popupItem->messageOpacity()*100) );
+    m_mainWid.mesTimeout->setValue(m_popupItem->messageTimeout());
+    m_mainWid.mesTimeout->setSuffix(ki18np(" millisecond", " milliseconds"));
+    m_mainWid.opacity->setValue(static_cast<int>(m_popupItem->messageOpacity() * 100));
     setCentralWidget(wid);
 
     setupGUI();
 }
 
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
-    KAboutData aboutData( QLatin1String("kgamepopupitemtest"), i18n("kgamepopupitemtest"), QLatin1String("0.1"));
+    KAboutData aboutData(QLatin1String("kgamepopupitemtest"), i18n("kgamepopupitemtest"), QLatin1String("0.1"));
     QApplication app(argc, argv);
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
@@ -88,34 +89,41 @@ int main(int argc, char** argv)
 
 void KGpiMainWindow::onPopupTL()
 {
-    QString str = !m_mainWid.showRichText->isChecked() ? "Heya! Popping up!" : "<font color=\"red\">Heya!</font> Click <a href=\"oh-oh-i-am-the-Link\">the link</a><br> and <b>a</b> message should appear in the scene";
+    QString str = !m_mainWid.showRichText->isChecked()
+        ? "Heya! Popping up!"
+        : "<font color=\"red\">Heya!</font> Click <a href=\"oh-oh-i-am-the-Link\">the link</a><br> and <b>a</b> message should appear in the scene";
     m_popupItem->showMessage(str, KGamePopupItem::TopLeft, m_replaceMode);
 }
 
 void KGpiMainWindow::onPopupTR()
 {
-    QString str = !m_mainWid.showRichText->isChecked() ? "Yippie! Popping up!" : "<font color=\"green\">Yippie!</font> Click <a href=\"oh-oh-i-am-the-Link\">the link</a><br> and <b>a</b> message should appear in the scene";
+    QString str = !m_mainWid.showRichText->isChecked()
+        ? "Yippie! Popping up!"
+        : "<font color=\"green\">Yippie!</font> Click <a href=\"oh-oh-i-am-the-Link\">the link</a><br> and <b>a</b> message should appear in the scene";
     m_popupItem->showMessage(str, KGamePopupItem::TopRight, m_replaceMode);
 }
 
 void KGpiMainWindow::onPopupBL()
 {
-    QString str = !m_mainWid.showRichText->isChecked() ? "Horray! Popping up!" : "<font color=\"yellow\">Horray</font><i>,comrades</i>! Click <a href=\"oh-oh-i-am-the-Link\">the link</a><br> and <b>a</b> message should appear in the scene";
+    QString str = !m_mainWid.showRichText->isChecked() ? "Horray! Popping up!"
+                                                       : "<font color=\"yellow\">Horray</font><i>,comrades</i>! Click <a href=\"oh-oh-i-am-the-Link\">the "
+                                                         "link</a><br> and <b>a</b> message should appear in the scene";
     m_popupItem->showMessage(str, KGamePopupItem::BottomLeft, m_replaceMode);
 }
 
 void KGpiMainWindow::onPopupBR()
 {
-    QString str = !m_mainWid.showRichText->isChecked() ? "Popping up! I like it, yeah!" : "<font color=\"blue\">Wow. Just blue WOW</font>! Click <a href=\"oh-oh-i-am-the-Link\">the link</a><br> and <b>a</b> message should appear in the scene";
+    QString str = !m_mainWid.showRichText->isChecked() ? "Popping up! I like it, yeah!"
+                                                       : "<font color=\"blue\">Wow. Just blue WOW</font>! Click <a href=\"oh-oh-i-am-the-Link\">the "
+                                                         "link</a><br> and <b>a</b> message should appear in the scene";
     m_popupItem->showMessage(str, KGamePopupItem::BottomRight, m_replaceMode);
 }
 
-void KGpiMainWindow::onLinkClicked(const QString& link)
+void KGpiMainWindow::onLinkClicked(const QString &link)
 {
-    QRectF visibleRect = m_mainWid.graphicsView->mapToScene( m_mainWid.graphicsView->contentsRect() ).boundingRect();
-    m_textItem->setText( "Hi! I'm the message that should appear :-). You clicked link: "+link );
-    m_textItem->setPos( visibleRect.left()+visibleRect.width()/2-m_textItem->boundingRect().width()/2,
-                        visibleRect.top()+visibleRect.height()/2 );
+    QRectF visibleRect = m_mainWid.graphicsView->mapToScene(m_mainWid.graphicsView->contentsRect()).boundingRect();
+    m_textItem->setText("Hi! I'm the message that should appear :-). You clicked link: " + link);
+    m_textItem->setPos(visibleRect.left() + visibleRect.width() / 2 - m_textItem->boundingRect().width() / 2, visibleRect.top() + visibleRect.height() / 2);
     m_textItem->show();
     QTimer::singleShot(2000, this, &KGpiMainWindow::hideTextItem);
 }
@@ -127,16 +135,16 @@ void KGpiMainWindow::hideTextItem()
 
 void KGpiMainWindow::onTimeoutChanged(int msec)
 {
-    m_popupItem->setMessageTimeout( msec );
+    m_popupItem->setMessageTimeout(msec);
 }
 
 void KGpiMainWindow::changeIcon()
 {
-    QString newPix = KFileDialog::getImageOpenUrl( KUrl(), this ).path();
-    if(newPix.isEmpty())
+    QString newPix = KFileDialog::getImageOpenUrl(KUrl(), this).path();
+    if (newPix.isEmpty())
         return;
     QPixmap pix(newPix);
-    m_popupItem->setMessageIcon( newPix );
+    m_popupItem->setMessageIcon(newPix);
 }
 
 void KGpiMainWindow::doInstantHide()
@@ -151,22 +159,22 @@ void KGpiMainWindow::doAnimatedHide()
 
 void KGpiMainWindow::changeOpacity(int opa)
 {
-    m_popupItem->setMessageOpacity(opa/100.0);
+    m_popupItem->setMessageOpacity(opa / 100.0);
 }
 
-void KGpiMainWindow::textColorChanged(const QColor& col)
+void KGpiMainWindow::textColorChanged(const QColor &col)
 {
     m_popupItem->setTextColor(col);
 }
 
-void KGpiMainWindow::bkgndColorChanged(const QColor& col)
+void KGpiMainWindow::bkgndColorChanged(const QColor &col)
 {
-    m_popupItem->setBackgroundBrush( col );
+    m_popupItem->setBackgroundBrush(col);
 }
 
 void KGpiMainWindow::replaceModeChanged()
 {
-    if(m_mainWid.leavePrevious->isChecked())
+    if (m_mainWid.leavePrevious->isChecked())
         m_replaceMode = KGamePopupItem::LeavePrevious;
     else
         m_replaceMode = KGamePopupItem::ReplacePrevious;
@@ -174,20 +182,21 @@ void KGpiMainWindow::replaceModeChanged()
 
 void KGpiMainWindow::sharpnessChanged(int idx)
 {
-    if( idx == 0 )
+    if (idx == 0)
         m_popupItem->setSharpness(KGamePopupItem::Square);
-    else if(idx == 1)
+    else if (idx == 1)
         m_popupItem->setSharpness(KGamePopupItem::Sharp);
-    else if(idx == 2)
+    else if (idx == 2)
         m_popupItem->setSharpness(KGamePopupItem::Soft);
-    else if(idx == 3)
+    else if (idx == 3)
         m_popupItem->setSharpness(KGamePopupItem::Softest);
-
 }
 
 void KGpiMainWindow::onPopupCenter()
 {
-    QString str = !m_mainWid.showRichText->isChecked() ? "Popping, popping, popping up!" : "<font color=\"red\">Heya!</font> Click <a href=\"oh-oh-i-am-the-Link\">the link</a><br> and <b>a</b> message should appear in the scene";
+    QString str = !m_mainWid.showRichText->isChecked()
+        ? "Popping, popping, popping up!"
+        : "<font color=\"red\">Heya!</font> Click <a href=\"oh-oh-i-am-the-Link\">the link</a><br> and <b>a</b> message should appear in the scene";
     m_popupItem->showMessage(str, KGamePopupItem::Center, m_replaceMode);
 }
 
